# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`gitlabinstall`](#gitlabinstall): GitLab installation
* [`gitlabinstall::gitlab`](#gitlabinstallgitlab): GitLab installation management
* [`gitlabinstall::nginx`](#gitlabinstallnginx): A short summary of the purpose of this class
* [`gitlabinstall::params`](#gitlabinstallparams): Basic module settings
* [`gitlabinstall::postgres`](#gitlabinstallpostgres): Install postgres database and pg_trgm extension
* [`gitlabinstall::ssl`](#gitlabinstallssl): A short summary of the purpose of this class

## Classes

### `gitlabinstall`

GitLab installation

#### Examples

##### 

```puppet
include gitlabinstall
```

#### Parameters

The following parameters are available in the `gitlabinstall` class.

##### `gitlab_package_ensure`

Data type: `String`

RPM package version. For example, 13.3.2-ce.0.el7 (see https://packages.gitlab.com/gitlab/gitlab-ce)

Default value: `'13.0.10-ce.0.el7'`

##### `external_url`

Data type: `Stdlib::HTTPUrl`

Configuring the external URL for GitLab
see [Configuring the external URL for GitLab](https://docs.gitlab.com/omnibus/settings/configuration.html#configuring-the-external-url-for-gitlab)

Default value: `'http://localhost'`

##### `database_password`

Data type: `Optional[String]`

PostgreSQL database password

Default value: ``undef``

##### `manage_cert_data`

Data type: `Boolean`

Whether provided certificate and key should be installed on server or not

Default value: ``true``

##### `cert_identity`

Data type: `Optional[String]`

Certificate name to use in order to lookup certificate data in Puppet Hiera

Default value: ``undef``

##### `external_postgresql_service`

Data type: `Boolean`

Using a non-packaged PostgreSQL database management server
see [Using a non-packaged PostgreSQL database management server](https://docs.gitlab.com/omnibus/settings/database.html#using-a-non-packaged-postgresql-database-management-server)

Default value: ``true``

##### `manage_postgresql_core`

Data type: `Boolean`

Whether to manage PostgreSQL core or not (installation, initialization,
service start)

Default value: ``true``

##### `non_bundled_web_server`

Data type: `Boolean`

Whether to use bundled into GitLab Nginx service or not

Default value: ``true``

##### `manage_nginx_core`

Data type: `Boolean`

Whether to manage core settings for Nginx or not (installation, nginx.conf
setup, service setup)

Default value: ``true``

##### `external_registry_service`

Data type: `Boolean`

Whether to integrate external Container registry into GitLab or not

Default value: ``false``

##### `registry_host`

Data type: `Optional[Stdlib::Fqdn]`

Registry endpoint without the scheme, the address that gets shown to the end user.

Default value: ``undef``

##### `registry_port`

Data type: `Integer`

Registry endpoint port, visible to the end user

Default value: `443`

##### `registry_api_url`

Data type: `Stdlib::HTTPUrl`

Registry API URL Gitlab should connect to

Default value: `'http://localhost:5000'`

##### `database_host`

Data type: `Variant[Stdlib::Fqdn, Stdlib::IP::Address]`



Default value: `'localhost'`

##### `monitoring_whitelist`

Data type: `Array[Stdlib::IP::Address]`



Default value: `[]`

### `gitlabinstall::gitlab`

GitLab installation management

#### Examples

##### 

```puppet
include gitlabinstall::gitlab
```

#### Parameters

The following parameters are available in the `gitlabinstall::gitlab` class.

##### `gitlab_package_ensure`

Data type: `String`

RPM package version. For example, 13.3.2-ce.0.el7 (see https://packages.gitlab.com/gitlab/gitlab-ce)

Default value: `$gitlabinstall::gitlab_package_ensure`

##### `log_dir`

Data type: `String`

Log directory to manage

Default value: `'/var/log/gitlab'`

##### `external_postgresql_service`

Data type: `Boolean`

Using a non-packaged PostgreSQL database management server
see [Using a non-packaged PostgreSQL database management server](https://docs.gitlab.com/omnibus/settings/database.html#using-a-non-packaged-postgresql-database-management-server)

Default value: `$gitlabinstall::external_postgresql_service`

##### `registry_api_url`

Data type: `Stdlib::HTTPUrl`

This is the Registry URL used internally that users do not need to interact with
it is gitlab_rails['registry_api_url'] setting in /etc/gitlab/gitlab.rb

Default value: `$gitlabinstall::registry_api_url`

##### `registry_host`

Data type: `Optional[Stdlib::Fqdn]`

Registry endpoint without the scheme, the address that gets shown to the end user.
it is gitlab_rails['registry_host'] setting in /etc/gitlab/gitlab.rb

Default value: `$gitlabinstall::registry_host`

##### `registry_port`

Data type: `Integer`

Registry endpoint port, visible to the end user
it is gitlab_rails['registry_port'] setting in /etc/gitlab/gitlab.rb

Default value: `$gitlabinstall::registry_port`

##### `registry_internal_key`

Data type: `Optional[String]`

Contents of the key that GitLab uses to sign the tokens.
It is registry['internal_key'] setting in /etc/gitlab/gitlab.rb
A certificate-key pair is required for GitLab and the external container
registry to communicate securely. You will need to create a certificate-key
pair, configuring the external container registry with the public certificate
and configuring GitLab with the private key

Default value: ``undef``

##### `registry_key_path`

Data type: `Optional[Stdlib::Unixpath]`

Path to the key that matches the certificate on the Registry side.
It is gitlab_rails['registry_key_path'] setting in /etc/gitlab/gitlab.rb
Custom file for Omnibus GitLab to write the contents of
registry['internal_key'] to. The file specified at `registry_key_path` gets
populated with the content specified by `internal_key`, each time reconfigure
is executed. If no file is specified, Omnibus GitLab will default it to
`/var/opt/gitlab/gitlab-rails/etc/gitlab-registry.key` and will populate it.

Default value: ``undef``

##### `packages_enabled`

Data type: `Boolean`

Enabling the Packages feature
see [GitLab Package Registry administration](https://docs.gitlab.com/ee/administration/packages/)

Default value: ``true``

##### `packages_storage_path`

Data type: `Optional[Stdlib::Unixpath]`

Local storage path for packages for Omnibus GitLab installation

Default value: `$gitlabinstall::params::packages_storage_path`

##### `ssl_cert`

Data type: `Optional[String]`

Content of x509 certificate to use for GitLab TLS setup

Default value: ``undef``

##### `ssl_key`

Data type: `Optional[String]`

Content of RSA private key to use for GitLab TLS setup

Default value: ``undef``

##### `repo_sslverify`

Data type: `Optional[Integer[0,1]]`

Set `sslverify` flag for Omnibus GitLab Yum repository

Default value: ``undef``

##### `monitoring_whitelist`

Data type: `Array[Stdlib::IP::Address]`

GitLab provides liveness and readiness probes to indicate service health.
To access monitoring resources, the requesting client IP needs to be
included in a whitelist.
See https://docs.gitlab.com/ee/administration/monitoring/ip_whitelist.html

Default value: `$gitlabinstall::monitoring_whitelist`

##### `database_password`

Data type: `String[8]`



Default value: `$gitlabinstall::database_password`

##### `manage_postgresql_core`

Data type: `Boolean`



Default value: `$gitlabinstall::manage_postgresql_core`

##### `database_host`

Data type: `String`



Default value: `$gitlabinstall::database_host`

##### `database_port`

Data type: `Variant[Integer, Pattern[/^[0-9]+$/]]`



Default value: `$gitlabinstall::params::database_port`

##### `database_username`

Data type: `String`



Default value: `$gitlabinstall::params::database_username`

##### `database_name`

Data type: `String`



Default value: `$gitlabinstall::params::database_name`

##### `non_bundled_web_server`

Data type: `Boolean`



Default value: `$gitlabinstall::non_bundled_web_server`

##### `manage_nginx_core`

Data type: `Boolean`



Default value: ``true``

##### `manage_cert_data`

Data type: `Boolean`



Default value: ``true``

##### `cert_identity`

Data type: `Optional[String]`



Default value: ``undef``

##### `gitlab_rails_host`

Data type: `String`



Default value: `'localhost'`

##### `gitlab_rails_port`

Data type: `Integer`



Default value: `8080`

##### `monitoring`

Data type: `Boolean`



Default value: ``false``

##### `external_registry_service`

Data type: `Boolean`



Default value: `$gitlabinstall::external_registry_service`

##### `mnt_distro`

Data type: `Optional[Stdlib::Unixpath]`



Default value: ``undef``

##### `mnt_distro_fstype`

Data type: `String`



Default value: `'ext4'`

##### `mnt_data`

Data type: `Optional[Stdlib::Unixpath]`



Default value: ``undef``

##### `mnt_data_fstype`

Data type: `String`



Default value: `'ext4'`

### `gitlabinstall::nginx`

A description of what this class does

#### Examples

##### 

```puppet
include gitlabinstall::nginx
```

#### Parameters

The following parameters are available in the `gitlabinstall::nginx` class.

##### `manage_service`

Data type: `Boolean`

Whether to manage Nginx core settings or not

Default value: `$gitlabinstall::manage_nginx_core`

##### `global_proxy_settings`

Data type: `Boolean`

Whether to enable global proxy cache settings or not. These settings will
reside in Nginx http context (therefore they are global). These settings
could be applied only if Nginx core is managed not here (so `manage_service`
is false)

Default value: ``true``

##### `manage_log_directory`

Data type: `Boolean`

Whether to create own log directory for GitLab or not. This directory
could be managed only if Nginx core is managed not here (so `manage_service`
is false)

Default value: ``true``

##### `monitoring_whitelist`

Data type: `Array[Stdlib::IP::Address]`

GitLab provides liveness and readiness probes to indicate service health.
To access monitoring resources, the requesting client IP needs to be
included in a whitelist.
See https://docs.gitlab.com/ee/administration/monitoring/ip_whitelist.html

Default value: `$gitlabinstall::monitoring_whitelist`

##### `daemon_user`

Data type: `String`



Default value: `$gitlabinstall::params::user`

##### `daemon_user_id`

Data type: `Integer`



Default value: `$gitlabinstall::params::user_id`

##### `daemon_group`

Data type: `String`



Default value: `$gitlabinstall::params::group`

##### `daemon_group_id`

Data type: `Integer`



Default value: `$gitlabinstall::params::group_id`

##### `nginx_user_home`

Data type: `String`



Default value: `$gitlabinstall::params::user_home`

##### `web_server_user_shell`

Data type: `String`



Default value: `$gitlabinstall::params::user_shell`

##### `ssl`

Data type: `Boolean`



Default value: ``false``

##### `ssl_cert_path`

Data type: `Optional[String]`



Default value: ``undef``

##### `ssl_key_path`

Data type: `Optional[String]`



Default value: ``undef``

##### `manage_document_root`

Data type: `Boolean`



Default value: ``false``

### `gitlabinstall::params`

Basic module settings

#### Examples

##### 

```puppet
include gitlabinstall::params
```

### `gitlabinstall::postgres`

Install postgres database and pg_trgm extension

#### Examples

##### 

```puppet
include gitlabinstall::postgres
```

#### Parameters

The following parameters are available in the `gitlabinstall::postgres` class.

##### `database_password`

Data type: `String[8]`



Default value: `$gitlabinstall::database_password`

##### `manage_service`

Data type: `Boolean`



Default value: `$gitlabinstall::manage_postgresql_core`

##### `database_username`

Data type: `String`



Default value: `$gitlabinstall::params::database_username`

##### `database_name`

Data type: `String`



Default value: `$gitlabinstall::params::database_name`

### `gitlabinstall::ssl`

A description of what this class does

#### Examples

##### 

```puppet
include gitlabinstall::ssl
```

#### Parameters

The following parameters are available in the `gitlabinstall::ssl` class.

##### `server_name`

Data type: `Stdlib::Fqdn`

GitLab server name (must be part of external_url)

##### `cert_identity`

Data type: `Optional[String]`

Certificate name to use in order to lookup certificate data in Puppet Hiera
Hiera lookup keys are `<cert_identity>_private` and `<cert_identity>_certificate`
where `<cert_identity>` is normalized value following next rules:

'*' -> 'wildcard', '.' -> '_', '-' -> '_', "'" ->  '_' and ' ' -> '_'

cert_identity must match either certificate Common Name or any of Subject
alternate DNS name

Default value: `$gitlabinstall::cert_identity`

##### `ssl_cert`

Data type: `Optional[String]`

Content of x509 certificate to use for GitLab TLS setup

Default value: ``undef``

##### `ssl_key`

Data type: `Optional[String]`

Content of RSA private key to use for GitLab TLS setup

Default value: ``undef``

##### `manage_cert_data`

Data type: `Boolean`

Whether provided certificate and key should be installed on server
or not

Default value: `$gitlabinstall::manage_cert_data`

